@@ -220,7 +220,13 @@ class Package:
         if 'node: command not found' in result:
             printandresult('brew install node')
 
-    
+    def run_extension_sh(self,file_list):
+        for file in file_list:
+            file_path = os.getcwd() + '/' + file
+            if os.path.exists(file_path):
+                warninglog("执行文件：" + file_path)
+                printandresult("sh " + file_path)
+
     def change_default_net_env(self,env):
         global ENV_CHANGE_COUNT
         filepath = self._search_xcodeproj() + "/project.pbxproj"
@@ -556,7 +562,7 @@ class Package:
         Cert().run_cert_syn()
 
 if __name__ == "__main__":
-    pass
+    # pass
     # Package().change_default_net_env("dev")
     # Package()._get_project_version()
     # Package().merge_code("Develop","zuche-test")
@@ -571,10 +577,12 @@ if __name__ == "__main__":
     
     # print(Package().check_node_env())
 
-    path = '/Users/v-sunweiwei/Desktop/saic/ios-shell-passenger'
-    os.chdir(path)
-    repo = Repo(path)
+    # path = '/Users/v-sunweiwei/Desktop/saic/ios-shell-passenger'
+    # os.chdir(path)
+    # repo = Repo(path)
     # printandresult('git ls-remote --tags origin')
     # printandresult('git show SRP_28722')
-    print('Author:' in repo.git.show('SRP_2872'))
+    # print('Author:' in repo.git.show('SRP_2872'))
+
+    Package().run_extension_sh(['branchS.sh'])
 
